@@ -7,11 +7,11 @@ except ImportError:
     from django.core.urlresolvers import reverse
 
 try:
-    from base64 import encodebytes as encode_base64
+    from base64 import b64encode as encode_base64
 except (ImportError, AttributeError):
     from base64 import encodestring as encode_base64
 
 try:
-    from base64 import decodebytes as decode_base64
+    from base64 import b64decode as decode_base64
 except (ImportError, AttributeError):
     from base64 import decodestring as decode_base64
